@@ -428,7 +428,7 @@ class Uv_maya(Uv, Slots_maya):
 		'''Rotate UV shells to run parallel with the most adjacent U or V axis of their bounding box.
 
 		:Parameters:
-			objects (str)(obj)(list) = Polygon mesh objects and/or components.
+			objects (str)(obj)(list): Polygon mesh objects and/or components.
 		'''
 		for obj in pm.ls(objects, objectsOnly=1):
 
@@ -448,9 +448,9 @@ class Uv_maya(Uv, Slots_maya):
 		'''Move sny selected objects to the given u and v coordinates.
 
 		:Parameters:
-			u (int) = u coordinate.
-			v (int) = v coordinate.
-			relative (bool) = Move relative or absolute.
+			u (int): u coordinate.
+			v (int): v coordinate.
+			relative (bool): Move relative or absolute.
 		'''
 		sel = self.uvShellSelection() #assure the correct selection mask.
 
@@ -494,8 +494,8 @@ class Uv_maya(Uv, Slots_maya):
 		'''Get All UV shells and their corresponding sets of faces.
 
 		:Parameters:
-			objects (obj)(list) = Polygon object(s) or Polygon face(s).
-			returnType (str) = The desired returned type. valid values are: 'shells', 'shellIDs'. If None is given, the full dict will be returned.
+			objects (obj)(list): Polygon object(s) or Polygon face(s).
+			returnType (str): The desired returned type. valid values are: 'shells', 'shellIDs'. If None is given, the full dict will be returned.
 
 		:Return:
 			(list)(dict) dependant on the given returnType arg. ex. {0L:[[MeshFace(u'pShape.f[0]'), MeshFace(u'pShape.f[1]')], 1L:[[MeshFace(u'pShape.f[2]'), MeshFace(u'pShape.f[3]')]}
@@ -536,7 +536,7 @@ class Uv_maya(Uv, Slots_maya):
 		'''Get the edges that make up any UV islands of the given objects.
 
 		:Parameters:
-			objects (str)(obj)(list) = Polygon mesh objects.
+			objects (str)(obj)(list): Polygon mesh objects.
 
 		:Return:
 			(list) uv border edges.
@@ -578,13 +578,13 @@ class Uv_maya(Uv, Slots_maya):
 	def transferUVs(self, frm, to='similar', tol=0.0, sampleSpace='component', deleteConstHist=True):
 		'''Transfer UV's from one group of objects to another.
 
-		:parameters:
-			frm (str)(obj)(list) = The objects to transfer uv's from.
-			to (str)(obj)(list) = The objects to transfer uv's to.
+		:Parameters:
+			frm (str)(obj)(list): The objects to transfer uv's from.
+			to (str)(obj)(list): The objects to transfer uv's to.
 					If 'similar' is given, the scene will be searched for similar objects.
 			tol (float) = 
-			sampleSpace (str) = Selects which space the attribute transfer is performed in. valid: 'world', 'local', 'component', 'topology'
-			deleteConstHist (bool) = Remove construction history for the objects transferring from.
+			sampleSpace (str): Selects which space the attribute transfer is performed in. valid: 'world', 'local', 'component', 'topology'
+			deleteConstHist (bool): Remove construction history for the objects transferring from.
 					Otherwise, the UV's will be lost should any of the frm objects be deleted.
 		'''
 		sampleSpace = {'world':0, 'local':1, 'component':4, 'topology':5}[sampleSpace]
